@@ -168,7 +168,7 @@ class Pipeline(TransformerMixin):
 
         return unpickle(meta_bytes)
 
-    def _get_meta_dict(self, requirements=None):
+    def _get_meta_dict(self, requirements=None, clean=True):
         environment_type = get_env_type()
         return {
             PIPELINE_TYPE: self.pipeline_type,
@@ -176,14 +176,14 @@ class Pipeline(TransformerMixin):
             VENV: environment_type,
             PY_VERSION: get_python_version(),
             REQUIREMEMTS: get_requirements(environment_type, requirements=requirements),
-            CONDA_ENV: get_conda_env(),
+            CONDA_ENV: get_conda_env(clean),
             VARIABLES: self.variables.copy(),
             DESCRIPTION: self.description,
             RAW: self.raw,
         }
 
-    def _get_meta(self, requirements=None):
-        return cloudpickle.dumps(_copy(self._get_meta_dict(requirements)))
+    def _get_meta(self, requirements=None, clean=True):
+        return cloudpickle.dumps(_copy(self._get_meta_dict(requirements, clean)))
 
     @classmethod
     def _split_meta(cls, b):
@@ -196,17 +196,18 @@ class Pipeline(TransformerMixin):
             validate_path(path)
         return write_bytes(path, state)
 
-    def save(self, path, requirements=None):
+    def save(self, path, requirements=None, clean=True):
         """
-        @param path: output path
-        @param requirements: a list of requirements. if None - takes from pip
-        @param mlflow: if True, export as mlflow project - not working on s3:path
+        @param path: str : output path
+        @param requirements: list[str]: a list of requirements. if None - takes from pip
+        @param clean: str: If True, clean some packages which are not available on conda (ignored if not on conda)
+        @param mlflow: bool: if True, export as mlflow project - not working on s3:path
         @param kwargs: Extra parameters to pass to mlflow.*.save_model
         @return: same path the pipeline was saved to
         """
 
         state_to_write = Pipeline.BYTES_SIGNETURE + self._get_meta(
-            requirements) + Pipeline.BYTE_DELIMITER + self._dumps()
+            requirements, clean) + Pipeline.BYTE_DELIMITER + self._dumps()
         return self._save_state(path, state_to_write)
 
     def validate(self, df=None, check_na=True, verbose=True):
